@@ -117,8 +117,10 @@ class ATagPagesView(WagtailBakeryView):
     def get_url(self, obj):
         site = obj.content_object.get_site()
         index_blog = self.model_index.objects.in_site(site).first()
-        blog_index_url = index_blog.relative_url(site)
-        return '%s' % blog_index_url + 'tags/%s' % obj.tag.slug + '/'
+        if index_blog:
+            blog_index_url = index_blog.relative_url(site)
+            return '%s' % blog_index_url + 'tags/%s' % obj.tag.slug + '/'
+        return None
 
     def get_queryset(self):
         return self.model_tag.objects.all().distinct()
