@@ -87,6 +87,18 @@ if not is_model_registered('cms', 'Person'):
 
     __all__.append('Person')
 
+
+from .snippets.gallery import AGallery
+
+if not is_model_registered('cms', 'Gallery'):
+    @register_snippet
+    class Gallery(AGallery):
+        pass
+
+
+    __all__.append('Gallery')
+
+
 #  Pages
 
 
