@@ -157,7 +157,7 @@ class ABlogPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
         return context
 
 
-class ABlogIndexPage(TagMixin, AmpMixin, WagtailPageBakeryModel, GenericPage):
+class ABlogIndexPage(TagMixin, AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
     subpage_types = ['BlogPage']
     template = '%s/blog_index_page.html' % constants.PAGES_TEMPLATES_PATH
     bg_desktop = StreamField([
