@@ -56,6 +56,10 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
 
     primary_color_uks = models.CharField(default='', blank=True, max_length=20)
     primary_bg_color = models.CharField(default='', blank=True, max_length=20)
+    primary_inverse_color_uks = models.CharField(default='', blank=True, max_length=20)
+    primary_inverse_bg_color = models.CharField(default='', blank=True, max_length=20)
+    secondary_color_uks = models.CharField(default='', blank=True, max_length=20)
+    secondary_bg_color = models.CharField(default='', blank=True, max_length=20)
 
     logo_header_primary = StreamField([
         ('image', ImageChooserBlock(label="Image - ratio 200x55")),
@@ -203,8 +207,14 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         FieldPanel('brand_name'),
         FieldPanel('brand_short_name'),
         FieldPanel('brand_description'),
+
         FieldPanel('primary_color_uks'),
         FieldPanel('primary_bg_color'),
+        FieldPanel('primary_inverse_color_uks'),
+        FieldPanel('primary_inverse_bg_color'),
+        FieldPanel('secondary_color_uks'),
+        FieldPanel('secondary_bg_color'),
+
         StreamFieldPanel('logo_header_primary'),
         StreamFieldPanel('logo_header_secondary'),
         ImageChooserPanel('favicon'),
