@@ -26,49 +26,73 @@ class MyFormBuilder(FormBuilder):
     def create_singleline_field(self, field, options):
         options['max_length'] = 255
         return django.forms.CharField(
-            widget=django.forms.TextInput(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.TextInput(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
     def create_multiline_field(self, field, options):
         return django.forms.CharField(
-            widget=django.forms.Textarea(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.Textarea(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
     def create_email_field(self, field, options):
         return django.forms.EmailField(
-            widget=django.forms.EmailInput(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.EmailInput(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
     def create_url_field(self, field, options):
         return django.forms.URLField(
-            widget=django.forms.URLInput(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.URLInput(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
     def create_number_field(self, field, options):
         return django.forms.DecimalField(
-            widget=django.forms.NumberInput(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.NumberInput(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
     def create_checkbox_field(self, field, options):
         return django.forms.BooleanField(
-            widget=django.forms.CheckboxInput(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.CheckboxInput(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
     def create_date_field(self, field, options):
         return django.forms.DateField(
-            widget=django.forms.DateInput(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.DateInput(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
     def create_datetime_field(self, field, options):
         return django.forms.DateTimeField(
-            widget=django.forms.DateTimeInput(attrs={'placeholder': field.placeholder}),
+            widget=django.forms.DateTimeInput(attrs={
+                'placeholder': field.placeholder,
+                'required': field.required
+            }),
             **options
         )
 
