@@ -6,6 +6,7 @@ from wagtail.embeds.embeds import get_embed
 from wagtail.embeds.exceptions import EmbedException
 
 from webspace.loader import get_model
+from webspace.cms import constants
 
 register = template.Library()
 logger = logging.getLogger('forms')
@@ -108,6 +109,25 @@ def myimg(img, params):
     return img.get_rendition(params)
 
 
+@register.filter
+def theme_settings(theme, site):
+    themes = {
+        constants.THEME_SPACE: {
+            'colors_uks': site.primary_color_uks,
+            'bg_color': site.primary_bg_color,
+        },
+        constants.THEME_SPACE_INVERSE: {
+            'colors_uks': site.primary_inverse_color_uks,
+            'bg_color': site.primary_inverse_bg_color,
+        },
+        constants.THEME_LIGHT: {
+            'colors_uks': site.secondary_color_uks,
+            'bg_color': site.secondary_bg_color,
+        },
+    }
+    return themes[theme] if theme in themes else None
+
+
 @register.filter
 def debug(item):
     import pdb
